==> silk-0.11.2.tar.gz: silk-0.11.2/src/rwfilter/cfg_lexer.h <==
/*
** Copyright (C) 2004-2007 by Carnegie Mellon University.
**
** @OPENSOURCE_HEADER_START@
**
** Use of the SILK system and related source code is subject to the terms
** of the following licenses:
**
** GNU Public License (GPL) Rights pursuant to Version 2, June 1991
** Government Purpose License Rights (GPLR) pursuant to DFARS 252.225-7013
**
** NO WARRANTY
**
** ANY INFORMATION, MATERIALS, SERVICES, INTELLECTUAL PROPERTY OR OTHER
** PROPERTY OR RIGHTS GRANTED OR PROVIDED BY CARNEGIE MELLON UNIVERSITY
** PURSUANT TO THIS LICENSE (HEREINAFTER THE "DELIVERABLES") ARE ON AN
** "AS-IS" BASIS. CARNEGIE MELLON UNIVERSITY MAKES NO WARRANTIES OF ANY
** KIND, EITHER EXPRESS OR IMPLIED AS TO ANY MATTER INCLUDING, BUT NOT
** LIMITED TO, WARRANTY OF FITNESS FOR A PARTICULAR PURPOSE,
** MERCHANTABILITY, INFORMATIONAL CONTENT, NONINFRINGEMENT, OR ERROR-FREE
** OPERATION. CARNEGIE MELLON UNIVERSITY SHALL NOT BE LIABLE FOR INDIRECT,
** SPECIAL OR CONSEQUENTIAL DAMAGES, SUCH AS LOSS OF PROFITS OR INABILITY
** TO USE SAID INTELLECTUAL PROPERTY, UNDER THIS LICENSE, REGARDLESS OF
** WHETHER SUCH PARTY WAS AWARE OF THE POSSIBILITY OF SUCH DAMAGES.
** LICENSEE AGREES THAT IT WILL NOT MAKE ANY WARRANTY ON BEHALF OF
** CARNEGIE MELLON UNIVERSITY, EXPRESS OR IMPLIED, TO ANY PERSON
** CONCERNING THE APPLICATION OF OR THE RESULTS TO BE OBTAINED WITH THE
** DELIVERABLES UNDER THIS LICENSE.
**
** Licensee hereby agrees to defend, indemnify, and hold harmless Carnegie
** Mellon University, its trustees, officers, employees, and agents from
** all claims or demands made against them (and any related losses,
** expenses, or attorney's fees) arising out of, or relating to Licensee's
** and/or its sub licensees' negligent use or willful misuse of or
** negligent conduct or willful misconduct regarding the Software,
** facilities, or other rights or assistance granted by Carnegie Mellon
** University under this License, including, but not limited to, any
** claims of product liability, personal injury, death, damage to
** property, or violation of any laws or regulations.
**
** Carnegie Mellon University Software Engineering Institute authored
** documents are sponsored by the U.S. Department of Defense under
** Contract F19628-00-C-0003. Carnegie Mellon University retains
** copyrights in all material produced under this contract. The U.S.
** Government retains a non-exclusive, royalty-free license to publish or
** reproduce these documents, or allow others to do so, for U.S.
** Government purposes only pursuant to the copyright license under the
** contract clause at 252.227.7013.
**
** @OPENSOURCE_HEADER_END@
*/
#ifndef _CFG_LEXER_H
#define _CFG_LEXER_H

#include "silk.h"

RCSIDENTVAR(rcsID_CFG_LEXER_H, "$SiLK: cfg_lexer.h 7345 2007-05-30 20:39:09Z mthomas $");

/*
**  cfg_lexer.h
**
**  Functions and vars shared between lex and yacc
**
*/

/* Provide some grammar debugging info, if necessary */
#define YYDEBUG 1

/* File to parse input */
extern FILE* yyin;

/* We'll need the current line number in case the config file has a
   parse error */
extern int cfg_lex_line_number;


int yyparse(void);

int yylex(void);

int yyerror(char *s);

#endif /* _CFG_LEXER_H */

/*
** Local Variables:
** mode:c
** indent-tabs-mode:nil
** c-basic-offset:4
** End:
*/

==> silk-0.11.7.tar.gz: silk-0.11.7/src/rwfilter/cfg_lexer.h <==
/*
** Copyright (C) 2004-2007 by Carnegie Mellon University.
**
** @OPENSOURCE_HEADER_START@
**
** Use of the SILK system and related source code is subject to the terms
** of the following licenses:
**
** GNU Public License (GPL) Rights pursuant to Version 2, June 1991
** Government Purpose License Rights (GPLR) pursuant to DFARS 252.225-7013
**
** NO WARRANTY
**
** ANY INFORMATION, MATERIALS, SERVICES, INTELLECTUAL PROPERTY OR OTHER
** PROPERTY OR RIGHTS GRANTED OR PROVIDED BY CARNEGIE MELLON UNIVERSITY
** PURSUANT TO THIS LICENSE (HEREINAFTER THE "DELIVERABLES") ARE ON AN
** "AS-IS" BASIS. CARNEGIE MELLON UNIVERSITY MAKES NO WARRANTIES OF ANY
** KIND, EITHER EXPRESS OR IMPLIED AS TO ANY MATTER INCLUDING, BUT NOT
** LIMITED TO, WARRANTY OF FITNESS FOR A PARTICULAR PURPOSE,
** MERCHANTABILITY, INFORMATIONAL CONTENT, NONINFRINGEMENT, OR ERROR-FREE
** OPERATION. CARNEGIE MELLON UNIVERSITY SHALL NOT BE LIABLE FOR INDIRECT,
** SPECIAL OR CONSEQUENTIAL DAMAGES, SUCH AS LOSS OF PROFITS OR INABILITY
** TO USE SAID INTELLECTUAL PROPERTY, UNDER THIS LICENSE, REGARDLESS OF
** WHETHER SUCH PARTY WAS AWARE OF THE POSSIBILITY OF SUCH DAMAGES.
** LICENSEE AGREES THAT IT WILL NOT MAKE ANY WARRANTY ON BEHALF OF
** CARNEGIE MELLON UNIVERSITY, EXPRESS OR IMPLIED, TO ANY PERSON
** CONCERNING THE APPLICATION OF OR THE RESULTS TO BE OBTAINED WITH THE
** DELIVERABLES UNDER THIS LICENSE.
**
** Licensee hereby agrees to defend, indemnify, and hold harmless Carnegie
** Mellon University, its trustees, officers, employees, and agents from
** all claims or demands made against them (and any related losses,
** expenses, or attorney's fees) arising out of, or relating to Licensee's
** and/or its sub licensees' negligent use or willful misuse of or
** negligent conduct or willful misconduct regarding the Software,
** facilities, or other rights or assistance granted by Carnegie Mellon
** University under this License, including, but not limited to, any
** claims of product liability, personal injury, death, damage to
** property, or violation of any laws or regulations.
**
** Carnegie Mellon University Software Engineering Institute authored
** documents are sponsored by the U.S. Department of Defense under
** Contract F19628-00-C-0003. Carnegie Mellon University retains
** copyrights in all material produced under this contract. The U.S.
** Government retains a non-exclusive, royalty-free license to publish or
** reproduce these documents, or allow others to do so, for U.S.
** Government purposes only pursuant to the copyright license under the
** contract clause at 252.227.7013.
**
** @OPENSOURCE_HEADER_END@
*/
#ifndef _CFG_LEXER_H
#define _CFG_LEXER_H

#include "silk.h"

RCSIDENTVAR(rcsID_CFG_LEXER_H, "$SiLK: cfg_lexer.h 7594 2007-06-20 16:50:23Z mwd $");

/*
**  cfg_lexer.h
**
**  Functions and vars shared between lex and yacc
**
*/


/* this list of definitions is from the automake info page */
#define yymaxdepth  cfg_lex_maxdepth
#define yyparse     cfg_lex_parse
#define yylex       cfg_lex_lex
#define yyerror     cfg_lex_error
#define yylval      cfg_lex_lval
#define yychar      cfg_lex_char
#define yydebug     cfg_lex_debug
#define yypact      cfg_lex_pact
#define yyr1        cfg_lex_r1
#define yyr2        cfg_lex_r2
#define yydef       cfg_lex_def
#define yychk       cfg_lex_chk
#define yypgo       cfg_lex_pgo
#define yyact       cfg_lex_act
#define yyexca      cfg_lex_exca
#define yyerrflag   cfg_lex_errflag
#define yynerrs     cfg_lex_nerrs
#define yyps        cfg_lex_ps
#define yypv        cfg_lex_pv
#define yys         cfg_lex_s
#define yy_yys      cfg_lex_yys
#define yystate     cfg_lex_state
#define yytmp       cfg_lex_tmp
#define yyv         cfg_lex_v
#define yy_yyv      cfg_lex_yyv
#define yyval       cfg_lex_val
#define yylloc      cfg_lex_lloc
#define yyreds      cfg_lex_reds
#define yytoks      cfg_lex_toks
#define yylhs       cfg_lex_yylhs
#define yylen       cfg_lex_yylen
#define yydefred    cfg_lex_yydefred
#define yydgoto     cfg_lex_yydgoto
#define yysindex    cfg_lex_yysindex
#define yyrindex    cfg_lex_yyrindex
#define yygindex    cfg_lex_yygindex
#define yytable     cfg_lex_yytable
#define yycheck     cfg_lex_yycheck
#define yyname      cfg_lex_yyname
#define yyrule      cfg_lex_yyrule


/* Provide some grammar debugging info, if necessary */
#define YYDEBUG 1

/* We'll need the current line number in case the config file has a
 * parse error */
extern int cfg_lex_line_number;

/* Function to do the parsing */
void cfg_config_parse(FILE *input);

int yyparse(void);

int yylex(void);

int yyerror(char *s);

#endif /* _CFG_LEXER_H */

/*
** Local Variables:
** mode:c
** indent-tabs-mode:nil
** c-basic-offset:4
** End:
*/
